object_pop_from_stack

Function object_pop_from_stack 

pub fn object_pop_from_stack(
    data_stack: &mut DataStack,
    registry: &Registry,
) -> Option<Object>
Moves the top stack value into an Object, looking its type up in the registry.

Puts the value back and returns None when the type is not registered.