Module plugins

Module plugins 

Structs

IncompatibleVersionsError
A plugin was built against an incompatible version of the platform.

Functions

install_plugin
Loads the plugin at path and lets it register its types and functions.
plugins_version
Returns the version of this crate, which plugins are checked against.